package Bencher::Util::CPANModules;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-01-20'; # DATE
our $DIST = 'Acme-CPANModulesUtil-Bencher'; # DIST
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Alias for Acme::CPANModulesUtil::Bencher

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Util::CPANModules - Alias for Acme::CPANModulesUtil::Bencher

=head1 VERSION

This document describes version 0.003 of Bencher::Util::CPANModules (from Perl distribution Acme-CPANModulesUtil-Bencher), released on 2021-01-20.

=head1 DESCRIPTION

This is an alias for L<Acme::CPANModulesUtil::Bencher> to help finding the
module easier.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesUtil-Bencher>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesUtil-Bencher>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModulesUtil-Bencher/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModulesUtil::Bencher>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
